crystal_toolkit.components.bandstructure module — Crystal Toolkit documentation

# crystal_toolkit.components.bandstructure module

class crystal_toolkit.components.bandstructure.BandstructureAndDosComponent(mpid=None, bandstructure_symm_line=None, density_of_states=None, id=None, **kwargs)

  Bases: `MPComponent`

  generate_callbacks(app, cache)

    Generate all callbacks associated with the layouts in this app. Assume that “suppress_callback_exceptions” is True, since it is not always guaranteed that all layouts will be displayed to the end user at all times, but it’s important the callbacks are defined on the server.

  static get_bandstructure_traces(bs, path_convention, energy_window=(-6.0, 10.0))
  static get_brillouin_zone_scene(bs: BandStructureSymmLine) → Scene
  static get_dos_traces(dos, dos_select, energy_window=(-6.0, 10.0))
  static get_figure(bs, dos, path_convention='sc', dos_select='ap', energy_window=(-6.0, 10.0))
  static get_ifermi_scene(bs: BandStructure) → Scene
  layout()
    Returns

      A Dash layout for the full component. Basic implementation

    provided, but should in general be overridden.

class crystal_toolkit.components.bandstructure.BandstructureAndDosPanelComponent(*args, **kwargs)

  Bases: `PanelComponent`

  property description
  property initial_contents
  property title
  update_contents(new_store_contents, *args)